==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/question.h <==
// Base clase for all question-sending classes.
//
// $Id: question.h,v 1.17 1994/07/16 17:38:30 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef QUESTION__
#define QUESTION__

#include "misc.h"
#include "error-codes.h"

class prot_a_LyStr;
class Ref_no;
class Connection;

// Send questions to LysKOM server

// Some things that are common to all different types of questions.
class question {
  public:
    question(Connection *conn);	// Allocates ref_no. The ref_no is
				// destructed when the reply comes.
    virtual ~question();	// Destructor.
    virtual  Status status();	// What is the status of this question?
    virtual  Status receive();	// Wait for reply.
    virtual  Kom_err error();	// The error code. Only 
				// valid if status() == error.
    virtual void parser(prot_a_LyStr &str) =0;
    void receive_err(int err);	// Deallocates ref_no.
  protected:
    Status state;		// Updated by all parsers.
    void deallocate_refno();	// Should be called from all
				// parser()s.
    Connection *port;
    int ref_no() const;
  private:
    Kom_err errcode;
    Ref_no *refno;
};

#endif

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/question.h <==
// Base clase for all question-sending classes.
//
// $Id: question.h,v 1.19 1995/11/14 00:35:09 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_QUESTION_H
#define KOMXX_QUESTION_H

#include "misc.h"
#include "error-codes.h"

class prot_a_LyStr;
class Ref_no;
class Connection;

// Send questions to LysKOM server

// Some things that are common to all different types of questions.
class question {
  public:
    question(Connection *conn);	// Allocates ref_no. The ref_no is
				// destructed when the reply comes.
    virtual ~question();	// Destructor.
    virtual  Status status();	// What is the status of this question?
    virtual  Status receive();	// Wait for reply.
    virtual  Kom_err error();	// The error code. Only 
				// valid if status() == st_error.
    virtual void parser(prot_a_LyStr &str) =0;
    void receive_err(int err);	// Deallocates ref_no.
  protected:
    Status state;		// Updated by all parsers.
    void deallocate_refno();	// Should be called from all
				// parser()s.
    Connection *port;
    int ref_no() const;
  private:
    Kom_err errcode;
    Ref_no *refno;
};

#endif
